summaryrefslogtreecommitdiff
path: root/libavformat/rm.h
diff options
context:
space:
mode:
authorAnton Khirnov <anton@khirnov.net>2011-02-20 11:04:12 +0100
committerRonald S. Bultje <rsbultje@gmail.com>2011-02-20 08:37:15 -0500
commitae628ec1fd7f54c102bf9e667a3edd404b9b9128 (patch)
treee23e5873e32189d50147e7a73956e326f3f1e407 /libavformat/rm.h
parent70aa916e4630bcec14439a2d703074b6d4c890a8 (diff)
avio: rename ByteIOContext to AVIOContext.
Signed-off-by: Ronald S. Bultje <rsbultje@gmail.com>
Diffstat (limited to 'libavformat/rm.h')
-rw-r--r--libavformat/rm.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/libavformat/rm.h b/libavformat/rm.h
index 2d4656aa11..6de10924ab 100644
--- a/libavformat/rm.h
+++ b/libavformat/rm.h
@@ -41,7 +41,7 @@ extern AVInputFormat ff_rdt_demuxer;
* Read the MDPR chunk, which contains stream-specific codec initialization
* parameters.
*
* @param s context containing RMContext and ByteIOContext for stream reading
* @param pb context to read the data from
* @param st the stream that the MDPR chunk belongs to and where to store the
* parameters read from the chunk into
@@ -49,14 +49,14 @@ extern AVInputFormat ff_rdt_demuxer;
* @param codec_data_size size of the MDPR chunk
* @return 0 on success, errno codes on error
*/
-int ff_rm_read_mdpr_codecdata (AVFormatContext *s, ByteIOContext *pb,
+int ff_rm_read_mdpr_codecdata (AVFormatContext *s, AVIOContext *pb,
AVStream *st, RMStream *rst,
int codec_data_size);
/**
* Parse one rm-stream packet from the input bytestream.
*
* @param s context containing RMContext and ByteIOContext for stream reading
* @param pb context to read the data from
* @param st stream to which the packet to be read belongs
* @param rst Real-specific stream information
@@ -70,7 +70,7 @@ int ff_rm_read_mdpr_codecdata (AVFormatContext *s, ByteIOContext *pb,
* value >0 means that no data was placed in pkt, but that cached
* data is available by calling ff_rm_retrieve_cache().
*/
-int ff_rm_parse_packet (AVFormatContext *s, ByteIOContext *pb,
+int ff_rm_parse_packet (AVFormatContext *s, AVIOContext *pb,
AVStream *st, RMStream *rst, int len,
AVPacket *pkt, int *seq, int flags, int64_t ts);
@@ -82,7 +82,7 @@ int ff_rm_parse_packet (AVFormatContext *s, ByteIOContext *pb,
* a positive number, the amount of cached packets. Using this function, each
* of those packets can be retrieved sequentially.
*
* @param s context containing RMContext and ByteIOContext for stream reading
* @param pb context to read the data from
* @param st stream that this packet belongs to
* @param rst Real-specific stream information
@@ -90,7 +90,7 @@ int ff_rm_parse_packet (AVFormatContext *s, ByteIOContext *pb,
* @return the number of samples left for subsequent calls to this same
* function, or 0 if all samples have been retrieved.
*/
-int ff_rm_retrieve_cache (AVFormatContext *s, ByteIOContext *pb,
+int ff_rm_retrieve_cache (AVFormatContext *s, AVIOContext *pb,
AVStream *st, RMStream *rst, AVPacket *pkt);
/**
@@ -41,7 +41,7 @@ extern AVInputFormat ff_rdt_demuxer;
* parameters.
*
- * @param s context containing RMContext and ByteIOContext for stream reading
+ * @param s context containing RMContext and AVIOContext for stream reading
* @param pb context to read the data from
* @param st the stream that the MDPR chunk belongs to and where to store the
@@ -49,14 +49,14 @@ extern AVInputFormat ff_rdt_demuxer;
* Parse one rm-stream packet from the input bytestream.
*
- * @param s context containing RMContext and ByteIOContext for stream reading
+ * @param s context containing RMContext and AVIOContext for stream reading
* @param pb context to read the data from
* @param st stream to which the packet to be read belongs
@@ -82,7 +82,7 @@ int ff_rm_parse_packet (AVFormatContext *s, ByteIOContext *pb,
* of those packets can be retrieved sequentially.
*
- * @param s context containing RMContext and ByteIOContext for stream reading
+ * @param s context containing RMContext and AVIOContext for stream reading
* @param pb context to read the data from
* @param st stream that this packet belongs to